hatchling: Modern, extensible Python build backend
==================================================

Description
-----------

Modern, extensible Python build backend

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/hatchling/

